NVIDIA Index
============

This package adds the address of the NVIDIA Private Python Package Index to
the user's environment.

For more information, please refer to https://github.com/nvidia/tensorflow/

This package can be installed as follows:

.. code-block:: bash

    pip install nvidia-pyindex
